==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/AzureWorkloadAutoProtectionIntentArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.AzureWorkloadAutoProtectionIntentArgs.builder
import com.pulumi.azurenative.recoveryservices.kotlin.enums.BackupManagementType
import com.pulumi.azurenative.recoveryservices.kotlin.enums.ProtectionStatus
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Azure Recovery Services Vault specific protection intent item.
 * @property backupManagementType Type of backup management for the backed up item.
 * @property itemId ID of the item which is getting protected, In case of Azure Vm , it is ProtectedItemId
 * @property policyId ID of the backup policy with which this item is backed up.
 * @property protectionIntentItemType backup protectionIntent type.
 * Expected value is 'AzureWorkloadAutoProtectionIntent'.
 * @property protectionState Backup state of this backup item.
 * @property sourceResourceId ARM ID of the resource to be backed up.
 */
public data class AzureWorkloadAutoProtectionIntentArgs(
    public val backupManagementType: Output<Either<String, BackupManagementType>>? = null,
    public val itemId: Output<String>? = null,
    public val policyId: Output<String>? = null,
    public val protectionIntentItemType: Output<String>,
    public val protectionState: Output<Either<String, ProtectionStatus>>? = null,
    public val sourceResourceId: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.AzureWorkloadAutoProtectionIntentArgs> {
    override fun toJava():
        com.pulumi.azurenative.recoveryservices.inputs.AzureWorkloadAutoProtectionIntentArgs =
        com.pulumi.azurenative.recoveryservices.inputs.AzureWorkloadAutoProtectionIntentArgs.builder()
            .backupManagementType(
                backupManagementType?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .itemId(itemId?.applyValue({ args0 -> args0 }))
            .policyId(policyId?.applyValue({ args0 -> args0 }))
            .protectionIntentItemType(protectionIntentItemType.applyValue({ args0 -> args0 }))
            .protectionState(
                protectionState?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .sourceResourceId(sourceResourceId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AzureWorkloadAutoProtectionIntentArgs].
 */
@PulumiTagMarker
public class AzureWorkloadAutoProtectionIntentArgsBuilder internal constructor() {
    private var backupManagementType: Output<Either<String, BackupManagementType>>? = null

    private var itemId: Output<String>? = null

    private var policyId: Output<String>? = null

    private var protectionIntentItemType: Output<String>? = null

    private var protectionState: Output<Either<String, ProtectionStatus>>? = null

    private var sourceResourceId: Output<String>? = null

    /**
     * @param value Type of backup management for the backed up item.
     */
    @JvmName("gwmsjkcmkalmdfow")
    public suspend fun backupManagementType(`value`: Output<Either<String, BackupManagementType>>) {
        this.backupManagementType = value
    }

    /**
     * @param value ID of the item which is getting protected, In case of Azure Vm , it is ProtectedItemId
     */
    @JvmName("dtydyhwthfkuesde")
    public suspend fun itemId(`value`: Output<String>) {
        this.itemId = value
    }

    /**
     * @param value ID of the backup policy with which this item is backed up.
     */
    @JvmName("helwuqpmsgthvolq")
    public suspend fun policyId(`value`: Output<String>) {
        this.policyId = value
    }

    /**
     * @param value backup protectionIntent type.
     * Expected value is 'AzureWorkloadAutoProtectionIntent'.
     */
    @JvmName("pofpoyqsutfhdfdh")
    public suspend fun protectionIntentItemType(`value`: Output<String>) {
        this.protectionIntentItemType = value
    }

    /**
     * @param value Backup state of this backup item.
     */
    @JvmName("lsneekwpxvlqnkec")
    public suspend fun protectionState(`value`: Output<Either<String, ProtectionStatus>>) {
        this.protectionState = value
    }

    /**
     * @param value ARM ID of the resource to be backed up.
     */
    @JvmName("uqbdrqyebebdyifm")
    public suspend fun sourceResourceId(`value`: Output<String>) {
        this.sourceResourceId = value
    }

    /**
     * @param value Type of backup management for the backed up item.
     */
    @JvmName("ecdrcyhgmjpsurxg")
    public suspend fun backupManagementType(`value`: Either<String, BackupManagementType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.backupManagementType = mapped
    }

    /**
     * @param value Type of backup management for the backed up item.
     */
    @JvmName("gnqmaxwfuinukpqq")
    public fun backupManagementType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, BackupManagementType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.backupManagementType = mapped
    }

    /**
     * @param value Type of backup management for the backed up item.
     */
    @JvmName("owogveaqgmdmdhlh")
    public fun backupManagementType(`value`: BackupManagementType) {
        val toBeMapped = Either.ofRight<String, BackupManagementType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.backupManagementType = mapped
    }

    /**
     * @param value ID of the item which is getting protected, In case of Azure Vm , it is ProtectedItemId
     */
    @JvmName("kxricqkdqqxtbeyk")
    public suspend fun itemId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.itemId = mapped
    }

    /**
     * @param value ID of the backup policy with which this item is backed up.
     */
    @JvmName("skgfuawnhtrhxnlh")
    public suspend fun policyId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.policyId = mapped
    }

    /**
     * @param value backup protectionIntent type.
     * Expected value is 'AzureWorkloadAutoProtectionIntent'.
     */
    @JvmName("qrxaorqkonpqtneg")
    public suspend fun protectionIntentItemType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.protectionIntentItemType = mapped
    }

    /**
     * @param value Backup state of this backup item.
     */
    @JvmName("eyskwkvysnsqwmgb")
    public suspend fun protectionState(`value`: Either<String, ProtectionStatus>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.protectionState = mapped
    }

    /**
     * @param value Backup state of this backup item.
     */
    @JvmName("wbmrvndpwuqflnue")
    public fun protectionState(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ProtectionStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.protectionState = mapped
    }

    /**
     * @param value Backup state of this backup item.
     */
    @JvmName("ccjkymuxuvjqfwvw")
    public fun protectionState(`value`: ProtectionStatus) {
        val toBeMapped = Either.ofRight<String, ProtectionStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.protectionState = mapped
    }

    /**
     * @param value ARM ID of the resource to be backed up.
     */
    @JvmName("yedaknsoicpebaqp")
    public suspend fun sourceResourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sourceResourceId = mapped
    }

    internal fun build(): AzureWorkloadAutoProtectionIntentArgs =
        AzureWorkloadAutoProtectionIntentArgs(
            backupManagementType = backupManagementType,
            itemId = itemId,
            policyId = policyId,
            protectionIntentItemType = protectionIntentItemType ?: throw
                PulumiNullFieldException("protectionIntentItemType"),
            protectionState = protectionState,
            sourceResourceId = sourceResourceId,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/AzureWorkloadAutoProtectionIntentArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.AzureWorkloadAutoProtectionIntentArgs.builder
import com.pulumi.azurenative.recoveryservices.kotlin.enums.BackupManagementType
import com.pulumi.azurenative.recoveryservices.kotlin.enums.ProtectionStatus
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Azure Recovery Services Vault specific protection intent item.
 * @property backupManagementType Type of backup management for the backed up item.
 * @property itemId ID of the item which is getting protected, In case of Azure Vm , it is ProtectedItemId
 * @property policyId ID of the backup policy with which this item is backed up.
 * @property protectionIntentItemType backup protectionIntent type.
 * Expected value is 'AzureWorkloadAutoProtectionIntent'.
 * @property protectionState Backup state of this backup item.
 * @property sourceResourceId ARM ID of the resource to be backed up.
 */
public data class AzureWorkloadAutoProtectionIntentArgs(
    public val backupManagementType: Output<Either<String, BackupManagementType>>? = null,
    public val itemId: Output<String>? = null,
    public val policyId: Output<String>? = null,
    public val protectionIntentItemType: Output<String>,
    public val protectionState: Output<Either<String, ProtectionStatus>>? = null,
    public val sourceResourceId: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.AzureWorkloadAutoProtectionIntentArgs> {
    override fun toJava():
        com.pulumi.azurenative.recoveryservices.inputs.AzureWorkloadAutoProtectionIntentArgs =
        com.pulumi.azurenative.recoveryservices.inputs.AzureWorkloadAutoProtectionIntentArgs.builder()
            .backupManagementType(
                backupManagementType?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .itemId(itemId?.applyValue({ args0 -> args0 }))
            .policyId(policyId?.applyValue({ args0 -> args0 }))
            .protectionIntentItemType(protectionIntentItemType.applyValue({ args0 -> args0 }))
            .protectionState(
                protectionState?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .sourceResourceId(sourceResourceId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AzureWorkloadAutoProtectionIntentArgs].
 */
@PulumiTagMarker
public class AzureWorkloadAutoProtectionIntentArgsBuilder internal constructor() {
    private var backupManagementType: Output<Either<String, BackupManagementType>>? = null

    private var itemId: Output<String>? = null

    private var policyId: Output<String>? = null

    private var protectionIntentItemType: Output<String>? = null

    private var protectionState: Output<Either<String, ProtectionStatus>>? = null

    private var sourceResourceId: Output<String>? = null

    /**
     * @param value Type of backup management for the backed up item.
     */
    @JvmName("pfjnlxvdfjwdjafh")
    public suspend fun backupManagementType(`value`: Output<Either<String, BackupManagementType>>) {
        this.backupManagementType = value
    }

    /**
     * @param value ID of the item which is getting protected, In case of Azure Vm , it is ProtectedItemId
     */
    @JvmName("mhrodgdtmtmypbdu")
    public suspend fun itemId(`value`: Output<String>) {
        this.itemId = value
    }

    /**
     * @param value ID of the backup policy with which this item is backed up.
     */
    @JvmName("majqgkanktqljvuv")
    public suspend fun policyId(`value`: Output<String>) {
        this.policyId = value
    }

    /**
     * @param value backup protectionIntent type.
     * Expected value is 'AzureWorkloadAutoProtectionIntent'.
     */
    @JvmName("ibtcitrqmflriasf")
    public suspend fun protectionIntentItemType(`value`: Output<String>) {
        this.protectionIntentItemType = value
    }

    /**
     * @param value Backup state of this backup item.
     */
    @JvmName("qvpljdxdcebjwgqy")
    public suspend fun protectionState(`value`: Output<Either<String, ProtectionStatus>>) {
        this.protectionState = value
    }

    /**
     * @param value ARM ID of the resource to be backed up.
     */
    @JvmName("jkgovsaugfwlshgw")
    public suspend fun sourceResourceId(`value`: Output<String>) {
        this.sourceResourceId = value
    }

    /**
     * @param value Type of backup management for the backed up item.
     */
    @JvmName("nretihdclebjksuc")
    public suspend fun backupManagementType(`value`: Either<String, BackupManagementType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.backupManagementType = mapped
    }

    /**
     * @param value Type of backup management for the backed up item.
     */
    @JvmName("aevfvdchjdcihwdl")
    public fun backupManagementType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, BackupManagementType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.backupManagementType = mapped
    }

    /**
     * @param value Type of backup management for the backed up item.
     */
    @JvmName("jjipknslxvrfjeht")
    public fun backupManagementType(`value`: BackupManagementType) {
        val toBeMapped = Either.ofRight<String, BackupManagementType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.backupManagementType = mapped
    }

    /**
     * @param value ID of the item which is getting protected, In case of Azure Vm , it is ProtectedItemId
     */
    @JvmName("fswpdmrfvplalopr")
    public suspend fun itemId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.itemId = mapped
    }

    /**
     * @param value ID of the backup policy with which this item is backed up.
     */
    @JvmName("mexdxialyewaeeyp")
    public suspend fun policyId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.policyId = mapped
    }

    /**
     * @param value backup protectionIntent type.
     * Expected value is 'AzureWorkloadAutoProtectionIntent'.
     */
    @JvmName("smniahqmdbquwyyg")
    public suspend fun protectionIntentItemType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.protectionIntentItemType = mapped
    }

    /**
     * @param value Backup state of this backup item.
     */
    @JvmName("udupxcqqxhpuojcw")
    public suspend fun protectionState(`value`: Either<String, ProtectionStatus>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.protectionState = mapped
    }

    /**
     * @param value Backup state of this backup item.
     */
    @JvmName("vibufkmuafkutbij")
    public fun protectionState(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ProtectionStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.protectionState = mapped
    }

    /**
     * @param value Backup state of this backup item.
     */
    @JvmName("kxswhuncsgbxbhoe")
    public fun protectionState(`value`: ProtectionStatus) {
        val toBeMapped = Either.ofRight<String, ProtectionStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.protectionState = mapped
    }

    /**
     * @param value ARM ID of the resource to be backed up.
     */
    @JvmName("rcbxpqbghdsycmlq")
    public suspend fun sourceResourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sourceResourceId = mapped
    }

    internal fun build(): AzureWorkloadAutoProtectionIntentArgs =
        AzureWorkloadAutoProtectionIntentArgs(
            backupManagementType = backupManagementType,
            itemId = itemId,
            policyId = policyId,
            protectionIntentItemType = protectionIntentItemType ?: throw
                PulumiNullFieldException("protectionIntentItemType"),
            protectionState = protectionState,
            sourceResourceId = sourceResourceId,
        )
}
